<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['%d association'] = '%d associazione';
$lang['%d associations'] = '%d associazioni';
$lang['%d album including'] = '%d album incluso';
$lang['%d albums including'] = '%d album inclusi';
$lang['%d physical'] = '%d fisico';
$lang['%d physical'] = '%d fisici';
$lang[' and %d virtual'] = ' e %d virtuale';
$lang[' and %d virtual'] = ' e %d virtuali';
$lang['%d album moved'] = '%d album spostato';
$lang['%d albums moved'] = '%d album spostati';
$lang['%d group'] = '%d gruppo';
$lang['%d groups'] = '%d gruppi';
$lang['%d member'] = '%d utente';
$lang['%d members'] = '%d utenti';
$lang['%d tag'] = '%d tag';
$lang['%d tags'] = '%d tags';
$lang['%d user comment rejected'] = '%d commento utente rifiutato';
$lang['%d user comments rejected'] = '%d commenti utente rifiutati';
$lang['%d user comment validated'] = '%d commento utente accettato';
$lang['%d user comments validated'] = '%d commenti utenti accettati';
$lang['%d user deleted'] = '%d utente cancellato';
$lang['%d users deleted'] = '%d utenti cancellati';
$lang['%d user'] = '%d utente';
$lang['%d users'] = '%d utenti';
$lang['%d waiting for validation'] = '%d in attesa di accettazione';
$lang['Actions'] = 'Azioni';
$lang['Activate'] = 'Attivare';
$lang['Add/delete a permalink'] = 'Aggiungere/cancellare un permalink';
$lang['Add a tag'] = 'Aggiungere un tag';
$lang['Add a user'] = 'Aggiungere un utente';
$lang['Add group'] = 'Aggiungere un gruppo';
$lang['Add'] = 'Aggiungere';
$lang['Allow user registration'] = 'Consentire l\'iscrizione degli \'ospiti\'';
$lang['Apply to sub-albums'] = 'Applicare al sub-album';
$lang['Associated'] = 'Associato a';
$lang['Batch management'] = 'Gestione per lotti';
$lang['Caddie management'] = 'Gestione del cestino';
$lang['Caddie'] = 'Cestino';
$lang['Albums authorized thanks to group associations'] = 'Album accessibili grazie all\'appartenenza ai gruppi';
$lang['Album manual order was saved'] = 'L\'ordinamento manuale degli album è stato salvato';
$lang['Album photos associated to the following albums: %s'] = 'Le foto dell\'album sono stati associati agli album seguenti : %s';
$lang['Check for upgrade failed for unknown reasons.'] = 'La verifica dell\'ultima versione sul server è fallita per le ragioni sconosciute.';
$lang['Check for upgrade'] = 'Controllo aggiornamenti';
$lang['Comments for all'] = 'Commenti per tutti';
$lang['Current name'] = 'Nome attuale';
$lang['Database'] = 'Database';
$lang['Deactivate'] = 'Disattivare';
$lang['Deactivate all'] = 'Disattivare tutto';
$lang['Delete Representant'] = 'Cancellare la copertina';
$lang['Delete selected tags'] = 'Cancellare i tags selezionati';
$lang['Delete selected users'] = 'Cancellare gli utenti selezionati';
$lang['Deletions'] = 'Eliminazione foto';
$lang['Deny selected groups'] = 'Vietare l\'accesso ai gruppi selezionati';
$lang['Deny selected users'] = 'Vietare l\'accesso agli utenti selezionati';
$lang['Description'] = 'Descrizione';
$lang['Display options'] = '0pzioni di visualizzazione';
$lang['Dissociated'] = 'Dissociata da';
$lang['Does not represent'] = 'Non rappresenta';
$lang['Edit selected tags'] = 'Modificare i tags selezionati';
$lang['Edit tags'] = 'Modificare i tags';
$lang['Email admins when a new user registers'] = 'Notificare gli amministratori dell\'iscrizione di un nuovo utente';
$lang['Email admins when a valid comment is entered'] = 'Notificare gli amministratori della presenza di un nuovo commento';
$lang['Email admins when a comment requires validation'] = 'Notificare gli amministratori quando un commento richiede un\'approvazione';
$lang['Environment'] = 'Ambiente';
$lang['Form'] = 'Modulo';
$lang['Gallery title'] = 'Titolo della galleria';
$lang['Grant selected groups'] = 'Dare l\'accesso ai gruppi selezionati';
$lang['Grant selected users'] = 'Dare l\'accesso agli utenti selezionati';
$lang['Group name'] = 'Nome del gruppo';
$lang['Groups'] = 'Gruppi';
$lang['Guests'] = 'Ospiti';
$lang['History'] = 'Cronologia';
$lang['Informations'] = 'Informazioni';
$lang['Install'] = 'Installare';
$lang['Link all album photos to a new album'] = 'Associare tutte le foto dell\'album ad un nuovo album';
$lang['Link all album photos to some existing albums'] = 'Associare tutte le foto dell\'album a degli album esistenti';
$lang['Linked albums'] = 'Album associati';
$lang['Lock gallery'] = 'Blocco della galleria';
$lang['Maintenance'] = 'Manutenzione';
$lang['Edit album permissions'] = 'Gestire i permessi di un album';
$lang['Manage permissions for group "%s"'] = 'Gestire i permessi per il gruppo "%s"';
$lang['Manage permissions for user "%s"'] = 'Gestire i permessi per l\'utente "%s"';
$lang['Manage tags'] = 'Gestire i tags';
$lang['Members'] = 'Membri';
$lang['Metadata synchronized from file'] = 'Metadati sincronizzati dal file';
$lang['Move albums'] = 'Spostare gli album';
$lang['Move'] = 'Spostare';
$lang['Name'] = 'Nome';
$lang['New name'] = 'Nuovo nome';
$lang['New parent album'] = 'Nuovo album principale';
$lang['New tag'] = 'Nuovo tag';
$lang['Number of comments per page'] = 'Numero di commenti per pagina';
$lang['Number of rates'] = 'Numero di voti';
$lang['Number of thumbnails to create'] = 'Numero di miniature da creare';
$lang['Only private albums are listed'] = 'Solo gli album privati sono elencati';
$lang['Operating system'] = 'Sistema operativo';
$lang['Options'] = 'Opzioni';
$lang['Other private albums'] = 'Altri album privati';
$lang['Page banner'] = 'Banner di pagina';
$lang['Parent album'] = 'Album principale';
$lang['Path'] = 'Percorso';
$lang['Permalink'] = 'Permalink';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Il permalink %s è stato usato precedentemente dall\'album %s. Cancellarlo prima dallo storico';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Il permalink deve essere composto unicamente dai caratteri seguenti : "a-zA-Z0-9", "-" o "_". Non deve essere numerico o iniziare con un numero seguito da "-"';
$lang['Permalink %s is already used by album %s'] = 'Il permalink %s è già in uso nell\'album %s';
$lang['Permalink history'] = 'Cronologia dei permalinks';
$lang['Permalinks'] = 'Permalinks';
$lang['Permission denied'] = 'Accesso non autorizzato';
$lang['Permission granted thanks to a group'] = 'Accesso autorizzato grazie al\'appartenenza ai gruppi';
$lang['Permission granted'] = 'Accesso autorizzato';
$lang['Photo informations updated'] = 'Le informazioni della foto sono state aggiornate';
$lang['Plugins'] = 'Plugins';
$lang['Position'] = 'Posizione';
$lang['Preferences'] = 'Preferenze';
$lang['Properties'] = 'Proprietà ';
$lang['Random photo'] = 'Foto a caso';
$lang['Rate date'] = 'Data del voto';
$lang['Rating by guests'] = 'Voti degli ospiti';
$lang['Rating'] = 'Voto';
$lang['Reject'] = 'Rifiutare';
$lang['Representant'] = 'Copertina';
$lang['Representation of albums'] = 'Rappresentazione degli album';
$lang['Representative'] = 'Rappresentativa';
$lang['Represents'] = 'Rappresenta';
$lang['Save order'] = 'Salvare l\'ordine';
$lang['Save to permalink history'] = 'Salvare nella cronologia dei permalinks';
$lang['Select at least one album'] = 'Selezionare almeno un album';
$lang['Select at least one photo'] = 'Scegliere almeno una foto';
$lang['Select at least one user'] = 'Scegliere almeno un\'utente';
$lang['Show info'] = 'Mostra le informazioni';
$lang['Site manager'] = 'Gestione dei siti';
$lang['Status'] = 'Stato';
$lang['Statistics'] = 'Statistiche';
$lang['Storage album'] = 'Album di memorizzazione';
$lang['Sum of rates'] = 'Somma dei voti';
$lang['Tag "%s" already exists'] = 'Il tag "%s" esiste già ';
$lang['Tag "%s" was added'] = 'Il tag "%s" è stato aggiunto';
$lang['Tag selection'] = 'Selezione dei tags';
$lang['The %d following tags were deleted'] = 'I %d tags seguenti sono stati cancellati';
$lang['Unable to check for upgrade.'] = 'Non è stato possibile controllare eventuali aggiornamenti.';
$lang['Uninstall'] = 'Disinstallare';
$lang['Use the default photo sort order (defined in the configuration file)']='Usare l\'ordinamento delle foto di default (cosi come definito nel file di configurazione)';
$lang['User comments validation'] = 'Approvare i commenti degli utenti';
$lang['Users'] = 'Utenti';
$lang['Validate'] = 'Approvare';
$lang['Validation'] = 'Richiedere l\'approvazione';
$lang['Version'] = 'Versione';
$lang['Virtual albums to move'] = 'Album virtuali da spostare';
$lang['Virtual album name'] = 'Nome dell\'album virtuale';
$lang['Webmaster cannot be deleted'] = 'Il Webmaster non può essere cancellato';
$lang['You are running on development sources, no check possible.'] = 'State lavorando con una versione di sviluppo, impossibile verificare l\'ultima versione.';
$lang['You cannot delete your account'] = 'Non potete cancellare il vostro account utente';
$lang['You cannot move an album in its own sub album'] = 'Non si può spostare un album nel proprio sub-album';
$lang['You need to confirm deletion'] = 'Dovete confermare la cancellazione';
$lang['add tags'] = 'Aggiungere i tags';
$lang['Associate to album'] = 'Associare all\'album';
$lang['associate to group'] = 'Associare al gruppo';
$lang['Authorized'] = 'Autorizzate';
$lang['Add a virtual album'] = 'Aggiungere un album virtuale';
$lang['Authorize users to add comments on selected albums'] = 'Autorizzare gli utenti ad aggiungere dei commenti  nell\'album selezionato';
$lang['The name of an album must not be empty'] = 'Il nome dell\'album non può rimanere vuoto';
$lang['Lock albums'] = 'Bloccare gli album';
$lang['Private'] = 'Album privato';
$lang['Public'] = 'Album pubblico';
$lang['Find a new representant by random'] = 'Scegliere una nuova copertina a caso';
$lang['Public / Private'] = 'Pubblica / Privata';
$lang['Manage authorizations for selected albums'] = 'Gestire le autorizzazioni per gli album selezionati';
$lang['Virtual album added'] = 'Album virtuale aggiunto';
$lang['Virtual album deleted'] = 'Album virtuale cancellato';
$lang['Access type'] = 'Tipo di accesso';
$lang['Comments'] = 'Commenti utente';
$lang['Information data registered in database'] = 'Informazioni registrate nel database';
$lang['Default display'] = 'Visualizzazione di default';
$lang['The gallery URL is not valid.'] = 'L\'URL della galleria non è valido.';
$lang['Main'] = 'Principale';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Il numero di commenti per pagina deve essere compreso tra 5 e 50.';
$lang['Configuration'] = 'Configurazione';
$lang['confirm'] = 'Confermare';
$lang['Date'] = 'Data';
$lang['delete album'] = 'Cancellare l\'album';
$lang['Dissociate from album'] = 'Dissociare dall\'album';
$lang['dissociate from group'] = 'Dissociare dal gruppo';
$lang['edit album permissions'] = 'modificare i permessi dell\'album';
$lang['Album updated successfully'] = 'Le informazioni dell\'album sono state aggiornate con successo.';
$lang['photos per page'] = 'foto per pagina';
$lang['High definition enabled'] = 'Alta definizione attiva';
$lang['File'] = 'File';
$lang['Filesize'] = 'Dimensione file';
$lang['first photo added on %s'] = 'prima foto aggiunta il %s';
$lang['Forbidden'] = 'Vietati';
$lang['global mode'] = 'Modalità globale';
$lang['group "%s" added'] = 'Gruppo "%s" aggiunto';
$lang['group "%s" deleted'] = 'Gruppo "%s" cancellato';
$lang['group "%s" updated'] = 'Gruppo "%s" aggiornato';
$lang['group'] = 'gruppo';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Il nome del gruppo non deve contenere " o \' e non deve essere vuoto.';
$lang['This name is already used by another group.'] = 'Questo nome è già  usato per un altro gruppo.';
$lang['High definition'] = 'Alta definizione';
$lang['jump to album'] = 'Andare all\'album';
$lang['jump to photo'] = 'Visionare la foto';
$lang['leave'] = 'Abbandonare';
$lang['Lock'] = 'Bloccare';
$lang['Locked'] = 'Bloccate';
$lang['manage album photos'] = 'Gestire le foto dell\'album';
$lang['manage sub-albums'] = 'Gestire i sub-album';
$lang['Manage'] = 'Gestire';
$lang['maximum height'] = 'Altezza massima';
$lang['maximum width'] = 'Larghezza massima';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Il tempo di esecuzione è scaduto, il processo deve continuare [Tempo stimato: %d secondo].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Il tempo di esecuzione è scaduto, il processo deve continuare [Tempo stimato: %d secondi].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Il tempo di preparazione dell\'elenco degli utenti per l\'invio dell\'email è limitato. Gli altri utenti non sono elencati';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Il tempo per l\'invio dell\'email è limitato. L\'invio delle altre email verra ignorato.';
$lang['To send ?'] = 'Inviare?';
$lang['Last send'] = 'Ultimo invio';
$lang['email'] = 'Email';
$lang['User'] = 'Utente';
$lang['Complementary mail content'] = 'Contenuto complementare per l\'email';
$lang['See you soon,'] = 'A presto,';
$lang['Go to'] = 'Andare a';
$lang['Hello'] = 'Ciao ';
$lang['New photos were added'] = 'Delle nuove foto sono state aggiunte';
$lang['on'] = ' il ';
$lang['between'] = 'tra il ';
$lang['and'] = ' e il ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Siete stati iscritti dal webmaster del sito per la ricezione di notifiche via email.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Vi siete iscritti per la ricezione di notifiche via email.';
$lang['To subscribe'] = 'Per iscrivervi';
$lang['If you encounter problems or have any question, please send a message to'] = 'Per qualsiasi domanda o problema inviare un messaggio a ';
$lang['[NBM] Problems or questions'] = '[NBM] Problemi o domande';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Siete stati cancellati dal webmaster dalla sottoscrizione alla ricezione di notifiche via email.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Vi siete cancellati dalla sottoscrizione alla ricezione di notifiche via email.';
$lang[', click on'] = ', cliccare su ';
$lang['To unsubscribe'] = 'Per cancellare la sottoscrizione ';
$lang['With blank value, gallery title will be used'] = 'Lasciando vuoto verrà  inviato il titolo della galleria';
$lang['Notification'] = 'Notifica';
$lang['Error when sending email to %s [%s].'] = 'Errore durante l\'invio dell\'email a %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Email inviata a %s [%s].';
$lang['%d mail was sent.'] = '%s email inviata.';
$lang['%d mails were sent.'] = '%s email inviate.';
$lang['%d mail was not sent.'] = '%s email non è stata inviata.';
$lang['%d mails were not sent.'] = '%s email non sono state inviate.';
$lang['No mail to send.'] = 'Nessuna email da inviare.';
$lang['There is no available subscribers to mail.'] = 'Nessun utente da notificare via email.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Un utente è da notificare solamente se ci sono nuovi elementi disponibili.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Solo il webmaster può accedere a queste informazioni, non gli amministratori.';
$lang['No user to send notifications by mail.'] = 'Nessun utente da notificare via email.';
$lang['New photos added'] = 'Nuove foto aggiunte';
$lang['Subscribe to notification by mail'] = 'Sottoscrivere alla notifica via email';
$lang['Unsubscribe from notification by mail'] = 'Cancella dalla notifica via email';
$lang['Parameter'] = 'Parametro';
$lang['Operation in progress'] = 'Elaborazione in corso.';
$lang['Continue processing treatment'] = 'Continuare il processo in corso...';
$lang['Complementary mail content'] = 'Contenuto aggiuntivo dell\'email';
$lang['Add detailed content'] = 'Invia contenuto dettagliato';
$lang['Send mail as'] = 'Inviare l\'email come';
$lang['Send mail to users'] = 'Invia un\'email agli utenti';
$lang['Send'] = 'Invio';
$lang['Options'] = 'Opzioni';
$lang['Subscribed'] = 'Iscritti';
$lang['Subscribe'] = 'Iscrizione';
$lang['Parameters'] = 'Parametri';
$lang['Select recipients'] = 'Selezionare i destinatari';
$lang['Subscribe/unsubscribe users'] = 'Iscrivere/Cancellare utenti';
$lang['Unsubscribed'] = 'Non iscritti';
$lang['%d parameter was updated.'] = '%d parametro è stato aggiornato.';
$lang['%d parameters were updated.'] = '%d parametri sono stati aggiornati.';
$lang['%d user was not updated.'] = '%d utente non è stato aggiornato.';
$lang['%d users were not updated.'] = '%d utenti non sono stati aggiornati.';
$lang['User %s [%s] was removed from the subscription list.'] = 'L\'utente %s [%s] è stato cancellato dall\'elenco degli iscritti.';
$lang['User %s [%s] was added to the subscription list.'] = 'L\'utente %s [%s] è stato aggiunto all\'elenco degli iscritti.';
$lang['%d user was updated.'] = '%d utente aggiornato.';
$lang['%d users were updated.'] = '%d utenti aggiornati.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'L\'utente %s [%s] non è stato cancellato dall\'elenco degli iscritti.';
$lang['User %s [%s] was not added to the subscription list.'] = 'L\'utente %s [%s] non è stato aggiunto all\'elenco degli iscritti.';
$lang['User %s [%s] added.'] = 'Utente %s [%s] aggiunto.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Attenzione: l\'iscrizione o la cancellazione invierà  un\'email agli utenti in questione';
$lang['Send mail on HTML format'] = 'Invio dell\'email in formato HTML';
$lang['Include display of recent photos grouped by dates'] = 'Includere le ultime foto per data';
$lang['Available only with HTML format'] = 'Disponibile unicamente con il formato HTML';
$lang['no write access'] = 'Nessun accesso in scrittura';
$lang['Permissions'] = 'Permessi';
$lang['private'] = 'privato';
$lang['public'] = 'pubblico';
$lang['Purge never used notification feeds'] = '"Ripulire" i flussi di notifica mai usati';
$lang['Purge sessions'] = '"Ripulire" le sessioni';
$lang['randomly represented'] = 'Copertina a caso';
$lang['registration date'] = 'Data di registrazione';
$lang['clean'] = 'Ripulire';
$lang['remove remote listing.xml file'] = 'Rimuovere il file remoto "listing.xml"';
$lang['generate listing'] = 'Generare il listing';
$lang['generate file listing.xml on remote site'] = 'Generare il file "listing.xml" sul sito remoto';
$lang['Create this site'] = 'Creare questo sito';
$lang['A local listing.xml file has been found for'] = 'Un file "listing.xml" è stato trovato per ';
$lang['read local listing.xml and update'] = 'Leggere il file "listing.xml" e aggiornare';
$lang['test'] = 'Verificare';
$lang['test this remote site'] = 'Verificare sito remoto';
$lang['remove tags'] = 'Rimuovere i tags';
$lang['Repair and optimize database'] = 'Riparare e ottimizzare il database';
$lang['selection'] = 'Selezione';
$lang['set to'] = 'Impostare a';
$lang['singly represented'] = 'Copertina fissa';
$lang['This site already exists'] = 'Questo sito esiste già ';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Creare un nuovo sito: (indicare URL verso "create_listing_file.php")';
$lang['created'] = 'creato';
$lang['Delete'] = 'Cancellare';
$lang['delete this site and all its attached elements'] = 'Cancellare questo sito e tutte le informazioni ad esso connessi';
$lang['an error happened'] = 'Si è verificato un\'errore';
$lang['file create_listing_file.php on remote site was not found'] = 'file "create_listing_file.php" non trovato sul sito remoto';
$lang['Local'] = 'Locale';
$lang['Remote'] = 'Remoto';
$lang['synchronize'] = 'Sincronizzare';
$lang['update the database from files'] = 'Aggiornare il database dai files';
$lang['status'] = 'Stato';
$lang['Directory'] = 'Directory';
$lang['sub-albums'] = 'sub-album';
$lang['synchronize metadata'] = 'Sincronizzare i metadati';
$lang['target'] = 'Target';
$lang['Thumbnail'] = 'Miniatura';
$lang['title'] = 'Titolo';
$lang['Album list management'] = 'Gestione degli album';
$lang['Piwigo configuration'] = 'Configurazione di Piwigo';
$lang['Edit album'] = 'Modificare un album';
$lang['Group management'] = 'Gestione gruppi';
$lang['User list'] = 'Elenco utenti';
$lang['Edit photo information'] = 'Modificare le informazioni della foto';
$lang['Thumbnail creation'] = 'Creazione delle miniature';
$lang['Database synchronization with files'] = 'Sincronizzazione database con i files';
$lang['all'] = 'Tutto';
$lang['photos without thumbnail (jpeg and png only)'] = 'foto senza miniature (solo jpeg e png)';
$lang['height must be a number superior to'] = 'l\'altezza deve essere un numero superiore a';
$lang['width must be a number superior to'] = 'la larghezza deve essere un numero superiore a';
$lang['for the file format'] = 'per il formato del file';
$lang['No missing thumbnail'] = 'Nessuna miniatura mancante';
$lang['Photo unreachable or no support'] = 'Foto non trovata o non supportata';
$lang['GD version'] = 'versione GD';
$lang['Miniaturization parameters'] = 'Parametri di miniaturizzazione';
$lang['generated in'] = 'generata in';
$lang['Results of miniaturization'] = 'Risultati della miniaturizzazione';
$lang['General statistics'] = 'Statistiche generali';
$lang['max time'] = 'tempo massimo';
$lang['average time'] = 'tempo medio';
$lang['min time'] = 'tempo minimo';
$lang['number of miniaturized photos'] = 'numero di foto miniaturizzate';
$lang['total time'] = 'tempo totale';
$lang['for this file format'] = 'per questo formato di file';
$lang['unit mode'] = 'Modalità singolo';
$lang['Unlocked'] = 'Sbloccate';
$lang['unset'] = 'Svuotare';
$lang['Update albums informations'] = 'Aggiornare le informazioni degli album';
$lang['Update photos information'] = 'Aggiornare le informazioni delle foto';
$lang['Synchronize'] = 'Sincronizzare';
$lang['reduce to single existing albums'] = 'Trattare un solo album';
$lang['Choose an option'] = 'Scegli un\'opzione';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'Mostrare tutte le informazioni possibili (album e foto aggiunti o eliminati)';
$lang['Piwigo version differs on the remote site'] = 'La versione di Piwigo differisce da quella sul server remoto';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'La versione del file "create_listing_file.php" sul server remoto deve essere la stessa di Piwigo';
$lang['listing.xml file was not found'] = 'Il file "listing.xml" non è stato trovato';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'Il file "listing.xml" non è stato trovato. Questo file è generato scegliendo il comando "genera l\'elenco" nella sezione "Amministrazione del sito"';
$lang['Error list'] = 'Elenco degli errori';
$lang['Errors caption'] = 'Significato degli errori';
$lang['Detailed informations'] = 'Informazioni dettagliate';
$lang['File/directory read error'] = 'Errore in letture del file/directory';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Non è possibile accedere al file o alla directory (probabilmente non esiste o l\'accesso è stato negato)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Ogni foto richiede una miniatura. La miniatura deve essere presente nella sottodirectory "thumbnail" della directory. Il nome del file della miniatura deve iniziare con il parametro di configurazione "prefix_thumbnail" e l\'estensione deve essere presente nell\'elenco seguente:';
$lang['missing thumbnail'] = 'miniature mancanti';
$lang['albums deleted in the database'] = 'album cancellati dal database';
$lang['photos deleted from the database'] = 'foto cancellate dal database';
$lang['photos candidates for metadata synchronization'] = 'foto in coda per la sincronizzazione dei metadati';
$lang['photos informations synchronized with files metadata'] = 'informazioni sulle foto sincronizzate con i metadati';
$lang['errors during synchronization'] = 'Si sono verificati errori durante la sincronizzazione';
$lang['albums added in the database'] = 'album aggiunti al database';
$lang['photos added in the database'] = 'foto aggiunte al database';
$lang['photos updated in the database'] = 'foto aggiornate nel database';
$lang['Search for new images in the directories'] = 'Cercare nuove immagini nelle directory';
$lang['added'] = 'aggiunto';
$lang['deleted'] = 'cancellato';
$lang['Metadata synchronization results'] = 'Risultato della sincronizzazione dei metadati';
$lang['only perform a simulation (no change in database will be made)'] = 'Solo simulazione (non sarà  fatta nessuna modifica nel database)';
$lang['[Simulation]'] = '[Simulazione]';
$lang['Simulation'] = 'Simulazione';
$lang['directories + files'] = 'Directory + file';
$lang['only directories'] = 'Solo directory';
$lang['synchronize files structure with database'] = 'Sincronizzare la struttura dei files con il database';
$lang['synchronize files metadata with database photos informations'] = 'Sincronizzare i metadati dei files con le informazioni delle foto del database';
$lang['even already synchronized photos'] = 'Anche le foto già  sincronizzate';
$lang['Used metadata'] = 'Metadati usati';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Il nome delle directory e dei files deve essere composto da lettere, numeri, "-", "_" o "."';
$lang['wrong filename'] = 'Nome file errato';
$lang['Upload'] = 'Caricare';
$lang['user "%s" added'] = 'utente "%s" aggiunto';
$lang['User status'] = 'Stato utente';
$lang['user_status_admin'] = 'Amministratore';
$lang['user_status_generic'] = 'Generico';
$lang['user_status_guest'] = 'Ospite';
$lang['user_status_normal'] = 'Utente';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Album virtuale';
$lang['Waiting'] = 'In attesa';
$lang['default'] = 'di default';
$lang['Toggle \'default group\' property'] = 'Invertire la proprietà  "gruppo di default"';
$lang['Advanced features'] = 'Funzioni avanzate';
$lang['Specials'] = 'Speciale';
$lang['Overall'] = 'Vista globale';
$lang['Year'] = 'Anno';
$lang['Month'] = 'Mese';
$lang['Day'] = 'Giorno';
$lang['Pages seen'] = 'Pagine viste';
$lang['Time'] = 'Ora';
$lang['IP'] = 'IP';
$lang['Element'] = 'Elemento';
$lang['Section'] = 'Selezione';
$lang['Tags'] = 'Tags';
$lang['Save page visits by guests'] = 'Registrare le pagine visitate dagli ospiti';
$lang['Save page visits by users'] = 'Registrare le pagine visitate dagli utenti';
$lang['Save page visits by administrators'] = 'Registrare le pagine visitate dagli amministratori';
$lang['An information email was sent to group "%s"'] = 'Un\'email informativa è stata inviata agli utenti del gruppo "%s"';
$lang['Send an information email to group members'] = 'Inviare un\'email informativa agli utenti di un gruppo';
$lang['Group'] = 'Gruppo';
$lang['[%s] Visit album %s'] = '[%s] Visita l\'album %s';
$lang['Hello,'] = 'Ciao,';
$lang['See you soon.'] = 'A presto.';
$lang['Discover album:'] = 'Scoprite l\'album:';
$lang['Mail content'] = 'Contenuto dell\'email';
$lang['none'] = 'nessuno';
$lang['high'] = 'high';
$lang['other'] = 'altro';
$lang['Element type'] = 'Tipo di elemento';
$lang['Image id'] = 'Id immagine';
$lang['Summary'] = 'Riassunto';
$lang['%d line filtered'] = '%d linea filtrata';
$lang['%d lines filtered'] = '%d linee filtrate';
$lang['%d guest'] = '%d ospite';
$lang['%d guests'] = '%d ospiti';
$lang['Hour'] = 'Ora';
$lang['guest'] = 'ospite';
$lang['default values'] = 'valore di default';
$lang['High filesize'] = 'Dimensione del file in Alta Risoluzione';
$lang['Guest cannot be deleted'] = 'L\'utente "ospite" non può essere cancellato';
$lang['Default user cannot be deleted'] = 'L\'utente di default non può essere cancellato';
$lang['Purge history detail'] = '"Ripulire" i dettagli dalla cronoligia';
$lang['Purge history summary'] = '"Ripulire" il sommario dalla cronoligia';
$lang['Check integrity'] = 'Controllo d\'integrità ';
$lang['Anomaly'] = 'Anomalia';
$lang['Correction'] = 'Correzione';
$lang['Automatic correction'] = 'Correzione automatica';
$lang['Impossible automatic correction'] = 'Correzione automatica impossibile';
$lang['Correction applied with success'] = 'Correzione applicata con successo';
$lang['Correction applied with error'] = 'Correzione applicata con errori';
$lang['%d anomaly has been detected.'] = 'individuata %d anomalia.';
$lang['%d anomalies have been detected.'] = 'individuate %d anomalie.';
$lang['%d anomaly has been corrected.'] = '%d anomalia corretta.';
$lang['%d anomalies have been detected corrected.'] = '%d anomalie corrette.';
$lang['%d anomaly has not been corrected.'] = 'non è stato possibile correggere %d anomalia.';
$lang['%d anomalies have not been corrected.'] = 'non è stato possibile correggere %d anomalie.';
$lang['Go to %s or %s for more informations'] = 'Recarsi su : %s o %s per avere più informazioni';
$lang['the forum'] = 'il Forum';
$lang['the wiki'] = 'la Wiki';
$lang['%s value is not correct file because exif are not supported'] = 'Il valore %s non è corretto perchè i files con dati EXIF non sono supportati';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s deve essere impostato su "false" nel vostro file local/config/config.inc.php';
$lang['Main "guest" user does not exist'] = 'L\'utente "ospite" principale non esiste';
$lang['Main "guest" user status is incorrect'] = 'Lo stato del\'utente "ospite" principale non è corretto';
$lang['Default user does not exist'] = 'L\'utente di default non esiste¹';
$lang['Main "webmaster" user does not exist'] = 'L\'utente "webmaster" principale non esiste più';
$lang['Main "webmaster" user status is incorrect'] = 'Lo stato dell\'utente "webmaster" principale non è corretto';
$lang['User "%s" created with "%s" like password'] = 'L\'utente "%s" creato con la password "%s"';
$lang['Status of user "%s" updated'] = 'Stato dell\'utente "%s" aggiornato';
$lang['add new photos to caddie'] = 'Aggiungere le nuove foto al cestino';
$lang['No display'] = 'Nessuna visualizzazione';
$lang['Classic display'] = 'Visualizzazione classica';
$lang['Hoverbox display'] = 'Visualizzazione durante il passaggio del mouse';
$lang['Mail address is obligatory for all users'] = 'L\'indirizzo email è obligatorio per tutti gli utenti';
$lang['Minimum privacy level'] = 'Livello minimo di privacy';
$lang['Privacy level'] = 'Livello di privacy';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Contatti';
$lang['Level 2'] = 'Amici';
$lang['Level 4'] = 'Famiglia';
$lang['Level 8'] = 'Amministratori';
$lang['Reinitialize check integrity'] = 'Reinizializzare controllo d\'integrità ';
$lang['Check all'] = 'Selezionare tutto';
$lang['Uncheck all'] = 'Deselezionare tutto';
$lang['Check automatic corrections'] = 'Selezionare correzioni automatiche';
$lang['Apply selected corrections'] = 'Applicare le correzioni selezionate';
$lang['Ignore selected anomalies'] = 'Ignorare le anomalie selezionate';
$lang['Refresh'] = 'Aggiornare';
$lang['The anomaly will be ignored until next application version'] = 'L\'anomalia verrà ignorata fino alla prossima versione dell\'applicazione';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'La correzione dell\'anomalia annulerà il fatto che sia ignorata';
$lang['%d anomaly has been ignored.'] = '%d anomalia è stata ignorata.';
$lang['%d anomalies have been ignored.'] = '%d anomalie sono state ignorate.';
$lang['Plugins which need upgrade'] = 'Plugins che necessitano di aggiornamento';
$lang['Plugin list'] = 'Elenco dei plugins';
$lang['Check for updates'] = 'Controllare aggiornamenti';
$lang['Other plugins'] = 'Altri plugins disponibili';
$lang['Last revisions'] = 'Ultimi aggiornamenti';
$lang['Delete'] = 'Cancellare';
$lang['Are you sure you want to install this plugin?'] = 'Siete sicuri di volere installare questo plugin?';
$lang['Are you sure you want to delete this plugin?'] = 'Siete sicuri di volere cancellare questo plugin?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Siete sicuri di volere installare questo aggiornamento? Dovete verificare che questo aggiornamento non necessiti una disinstallazione.';
$lang['%s has been successfully upgraded.'] = '%s è stato aggiornato con successo.';
$lang['Plugin has been successfully copied'] = 'Il plugin è stato copiato con successo.';
$lang['You might go to plugin list to install and activate it.'] = 'Recatevi nella lista dei plugins per installarlo ed attivarlo.';
$lang['Can\'t create temporary file.'] = 'È impossibile creare un file temporaneo.';
$lang['Can\'t download archive.'] = 'È impossibile scaricare l\'archivio.';
$lang['Can\'t read or extract archive.'] = 'È impossibile leggere o estrarre l\'archivio.';
$lang['An error occured during extraction (%s).'] = 'Si è verificato un\'errore durante l\'estrazione del file (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Verificate i permessi della cartella "plugins" e delle sue sotto cartelle (CHMOD).';
$lang['Can\'t connect to server.'] = 'Non è possibile connettersi al server.';
$lang['Purge compiled templates'] = 'Ripulire i templates compilati';
$lang['ACCESS_0'] = 'Accesso libero';
$lang['ACCESS_1'] = 'Accesso a tutti';
$lang['ACCESS_2'] = 'Accesso agli iscritti';
$lang['ACCESS_3'] = 'Accesso agli amministratori';
$lang['ACCESS_4'] = 'Accesso ai webmaster';
$lang['ACCESS_5'] = 'Nessun accesso';
$lang['Support'] = 'Forum';
$lang['Documentation'] = 'Documentazione';
$lang['A new version of Piwigo is available.'] = 'Una nuova versione di Piwigo è disponibile.';
$lang['Piwigo Administration'] = 'Amministrazione di Piwigo';
$lang['Piwigo version'] = 'Versione di Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'State già  usando l\'ultima versione di Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'La versione di %s [%s] installata non è compatible con la versione richiesta [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Dovete aggiornare il vostro sistema per poter sfruttare completamente l\'applicazione, altrimenti l\'applicazione non funzionerà correttamente, o non funzionerà per niente';
$lang['Deleted on'] = 'Cancellati su';
$lang['Last hit'] = 'Ultimo punteggio';
$lang['GD library is missing'] = 'la biblioteca GD è mancante';
$lang['Templates'] = 'Templates (modelli)';
$lang['Extend for templates'] = 'Estendere i templates';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Sostituzione dei templates originali con i vostri templates personalizzati dalla sottodirectory template-extension';
$lang['Replacers (customized templates)'] = 'Sostituzione (templates personalizzati)';
$lang['Original templates'] = 'Templates d\'origine';
$lang['Orphan tags deleted'] = 'Tag orfani cancellati';
$lang['Optional URL keyword'] = 'URL keyword opzionale';
$lang['Templates configuration has been recorded.'] = 'La configurazione dei templates è stata registrata.';
$lang['All optimizations have been successfully completed.'] = 'Tutte le ottimizzazioni sono state completate con successo.';
$lang['Optimizations have been completed with some errors.'] = 'Le ottimizzazioni sono state completate con alcuni errori.';
$lang['Modify information'] = 'Modifica le informazioni';
$lang['edit album'] = 'Modificare le informazioni dell\'album';
$lang['nothing'] = 'Niente';
$lang['overrides existing values with empty ones'] = 'Sovrascrivere i valori esistenti con quelli vuoti';
$lang['manage photo ranks'] = 'Gestire l\'ordinamento delle foto';
$lang['Manage photo ranks'] = 'Gestire l\'ordinamento delle foto';
$lang['Edit ranks'] = 'Modificare l\'ordine';
$lang['No photo in this album'] = 'Nessuna foto in quest\'album';
$lang['Images manual order was saved'] = 'L\'ordinamento manuale delle immagini è stato salvato';
$lang['ranks'] = 'posizioni';
$lang['By rank'] = 'Per posizione';
$lang['Manual order'] = 'Ordinamento manuale';
$lang['Drag to re-order'] = 'Clicca e trascina per riorganizzare';
$lang['Quick Local Synchronization'] = 'Sincronizzazione rapida';
$lang['No photo can be deleted'] = 'Nessuna foto può essere eliminata';
$lang['Delete selected photos'] = 'Eliminare le foto selezionate';
$lang['%d photo was deleted'] = '%d foto è stata cancellata';
$lang['%d photos were deleted'] = '%d foto sono state cancellate';
$lang['Downloads'] = 'Downloads';
$lang['Released on'] = 'Aggiunto il';
$lang['Number of downloads'] = 'Totale downloads';
$lang['Piwigo Announcements Newsletter'] = 'Newsletter Piwigo';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Rimanete in contatto con il progetto Piwigo, iscrivetevi alla newsletter di Piwigo Announcement. Riceverete un\'email quando una nuova versione sarà disponibile (a volte un bug di sicurezza viene corretto, è importante saperlo e quindi aggiornare) e quando ci saranno grandi eventi del progetto. Sono solamente alcune emails all\'anno';
$lang['Subscribe %s'] = 'Iscrivere %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Iscrivere %s alla newsletter Piwigo';
$lang['Purge search history'] = '"Pulire" la cronologia delle ricerche';
$lang['Hide'] = 'Nascondere';
$lang['Password is missing. Please enter the password.'] = 'Campo password vuoto. Prego inserire la password.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Campo conferma della password vuoto. Si prega di confermare la password scelta';
$lang['Password confirmation error.'] = 'Errore conferma della password.';
$lang['Allow users to edit their own comments'] = 'Autorizzare gli utenti a modificare i propri commenti';
$lang['Allow users to delete their own comments'] = 'Autorizzare gli utenti a cancellare i propri commenti';
$lang['Email administrators when a comment is modified'] = 'Inviare un\'email agli amministratori quando un commento viene modificato';
$lang['Email administrators when a comment is deleted'] = 'Inviare un\'email agli amministratori quando un commento viene cancellato';
$lang['Cannot delete the old permalink !'] = 'Non è possibile cancellare il vecchio permalink !';
$lang['Hit'] = 'punteggio';

$lang['Tools'] = 'Tools';
$lang['Photos'] = 'Foto';
$lang['Themes'] = 'Temi';
$lang['Instructions to use Piwigo'] = 'Istruzioni per l\'uso di Piwigo';
$lang['Installed Themes'] = 'Temi dettagliati';
$lang['Add New Theme'] = 'Aggiungere un tema';
$lang['Forbid this theme to users'] = 'Vietare questo tema agli utenti';
$lang['Set as default theme for unregistered and new users'] = 'Tema di default per gli ospiti e i nuovi utenti';
$lang['unknown'] = 'sconosciuto';

$lang['Upload Photos'] = 'Aggiungere foto';
$lang['Drop into album'] = 'Spostare nell\'album';
$lang['+ Add an upload box'] = '+ Aggiungere un altro campo di upload';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Creare la directory "% s" nella radice della vostra installazione Piwigo';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Dare i permessi in scrittura (chmod 777) alla directory "% s" nella radice della vostra installazione Piwigo';
$lang['existing album'] = 'album esistente';
$lang['create a new album'] = 'creare un nuovo album';
$lang['Album name'] = 'Nome dell\'album';
$lang['Album "%s" has been added'] = 'L\'Album "%s" è stato aggiunto';
$lang['Uploaded Photos'] = 'Foto aggiunte ';
$lang['%d photos uploaded'] = '%d foto aggiunte';
$lang['Privacy level set to "%s"'] = 'Livello di privacy "%s"';
$lang['Album "%s" now contains %d photos'] = 'L\'Album "%s" contiene adesso %d foto';
$lang['Manage this set of %d photos'] = 'Gestire questo set di %d foto';
$lang['Select files'] = 'Scegliere i file';
$lang['Everybody'] = 'Tutti';
$lang['Who can see these photos?'] = 'Chi può vedere queste foto?';
$lang['Who can see this photo?'] = 'Chi può vedere questa foto?';

$lang['The websize maximum width must be a number between %d and %d'] = 'La larghezza massima della foto con dimenzioni per il web deve essere un numero tra %d e %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'L\'altezza massima della foto con dimenzioni per il web deve essere un numero tra %d e %d';
$lang['The websize image quality must be a number between %d and %d'] = 'La qualità dell\'immagine per la foto con dimenzioni per il web deve essere un numero tra %d e %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'La larghezza massima della miniatura deve essere un numero tra %d e %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'L\'altezza massima della miniatura deve essere un numero tra %d e %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'La qualità  dell\'immagine per la miniatura deve essere un numero tra %d e %d';

$lang['Settings'] = 'Configurazione';
$lang['Web size photo'] = 'Dimensione foto web';
$lang['Resize'] = 'Ridimensionare';
$lang['Maximum Width'] = 'Larghezza massima';
$lang['pixels'] = 'pixels';
$lang['Maximum Height'] = 'Altezza massima';
$lang['Image Quality'] = 'Qualità  dell\'immagine';
$lang['Thumbnail'] = 'Miniatura';
$lang['Save Settings'] = 'Salvare impostazioni';
$lang['Your configuration settings are saved'] = 'La vostra configurazione è stata registrata';

$lang['Active Themes'] = 'Temi attivati';
$lang['Add write access to the "%s" directory'] = 'Aggiungere l\'accesso in scrittura per la directory "%s"';
$lang['Administration Home'] = 'Home Amministrazione';
$lang['Change Admin Colors'] = 'Modificare i colori dell\'amministrazione';
$lang['Delete this theme'] = 'Cancellare questo tema';
$lang['Directory does not exist'] = 'La directory non esiste';
$lang['Download,'] = 'Scaricare,';
$lang['FTP + Synchronization'] = 'FTP + Sincronizzazione';
$lang['Get Support on Piwigo Forum'] = 'Ottenere assistenza sul forum di Piwigo';
$lang['Help Me'] = 'Aiuto';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Non è stato possibile attivare questo tema, manca il tema principale (superiore): %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Impossibile cancellare questo tema. Altri temi dipendono da esso: %s';
$lang['Inactive Themes'] = 'Temi disattivati';
$lang['Install on your computer,'] = 'Installare sul vostro computer,';
$lang['Make this theme available to users'] = 'Rendere questo tema disponibile agli utenti';
$lang['Page end'] = 'Fine pagina';
$lang['Piwigo Uploader'] = 'Piwigo Uploader';
$lang['Read Piwigo Documentation'] = 'Leggere la documentazione di Piwigo';
$lang['Start pLoader and add your photos.'] = 'Avviare pLoader e aggiungere le vostre foto.';
$lang['Switch to clear or dark colors for administration'] = 'Scegliere il colore chiaro o scuro per l\'amministrazione';
$lang['Theme has been successfully installed'] = 'Il tema è stato installato con successo';
$lang['Visit Gallery'] = 'Visitare la galleria';
$lang['Visit Piwigo project website'] = 'Visitare il sito web del progetto Piwigo';

$lang['Guest Settings'] = 'Parametri ospite';
$lang['Main Page'] = 'Pagina principale';
$lang['Photo Page'] = 'Pagina della foto';
$lang['Activate Navigation Bar'] = 'Attivare barra di navigazione';
$lang['Activate Navigation Thumbnails'] = 'Attivare le miniature di navigazione';
$lang['Activate icon "%s"'] = 'Attivare l\'icona "%s"';
$lang['Activate field "%s"'] = 'Attivare il campo "%s"';
$lang['Photo Properties'] = 'Proprietà foto';


$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader significa <em>Piwigo Uploader</em>. Dal vostro computer, pLoader prepara le vostre foto e le trasferisce verso la vostra galleria foto Piwigo.';
$lang['Languages'] = 'Lingue';
$lang['Installed Languages'] = 'Lingue installate';
$lang['Add New Language'] = 'Aggiungere una lingua';
$lang['Language has been successfully installed'] = 'La lingua è stata installata con successo';
$lang['Allow user customization'] = 'Permettere la personalizzazione della visualizzazione';
$lang['Select:'] = 'Selezionare :';
$lang['None'] = 'Niente';
$lang['Invert'] = 'Invertire';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Non è possibile disattivare questo tema, ci deve essere almeno un tema attivo.';
$lang['Webmaster status is required.'] = 'Dovete avere lo stato di webmaster.';
$lang['Bound Theme'] = 'Tema legato';
$lang['Allow rating'] = 'Autorizzare le votazioni';
$lang['Select at least one comment'] = 'Selezionare almeno un commento';
$lang['Active Plugins'] = 'Plugins attivati';
$lang['Inactive Plugins'] = 'Plugins disabilitati';
$lang['Missing Plugins'] = 'Plugins mancanti';
$lang['Uninstalled Plugins'] = 'Plugins non installati';
$lang['By %s'] = 'Da %s';
$lang['Visit plugin site'] = 'Visitate il sito del plugin';
$lang['Active Languages'] = 'Lingue attivate';
$lang['Delete this language'] = 'Cancellare questa lingua';
$lang['Forbid this language to users'] = 'Vietare questa lingua agli utenti';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Impossibile disattivare questa lingua, prima impostare come default un altra lingua.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Impossibile disattivare questa lingua. Deve essere attiva almeno una lingua.';
$lang['Inactive Languages'] = 'Lingue disattivate';
$lang['Make this language available to users'] = 'Rendere questa lingua disponibile agli utenti';
$lang['Set as default language for unregistered and new users'] = 'Lingua di default per gli ospiti e nuovi utenti';
$lang['Add Photos'] = 'Aggiungere delle foto';
$lang['Download'] = 'Download';
$lang['Miscellaneous'] = 'Informazioni';
$lang['The following tag was deleted'] = 'Il tag seguente è stato cancellato';
$lang['Virtual Links'] = 'Collegamenti virtuali';
$lang['There is no other language available.'] = 'Non ci sono altre lingue disponibili.';
$lang['There is no other plugin available.'] = 'Non ci sono altri plugin disponibili.';
$lang['There is no other theme available.'] = 'Non ci sono altri temi disponibili.';
$lang['delete'] = 'Cancellare';
$lang['Add another set of photos'] = 'Aggiungi un altro set di foto';
$lang['Order of menubar items has been updated successfully.'] = 'L\'ordine degli elementi della barra dei menu è stato aggiornato con successo.';
$lang['This theme was not designed to be directly activated'] = 'Questo tema non è stato progettato per essere attivato direttamente';
$lang['Pending Comments'] = 'Commenti in attesa';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'Nel vostro file php.ini, la variabile upload_max_filesize (%sB) è più grande di post_max_size (%sB), è necessario modificare questa impostazione';
$lang['Exif extension not available, admin should disable exif use'] = 'L\'estensione Exif non è disponibile, un amministratore deve disabilitare l\'uso dei metadati Exif';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Il peso del file caricato supera il valore upload_max_filesize nel file php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Il peso totale dei file trasferiti supera il valore di post_max_size nel file php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Il peso del file caricato supera il valore di MAX_FILE_SIZE definito nel modulo HTML';
$lang['The uploaded file was only partially uploaded'] = 'Il file è stato caricato solo parzialmente';
$lang['No file was uploaded'] = 'Nessun file è stato caricato';
$lang['Missing a temporary folder'] = 'Impossibile trovare la directory temporanea';
$lang['Failed to write file to disk'] = 'Non è stato possibile scrivere il file sul server';
$lang['File upload stopped by extension'] = 'Il trasferimento del file è stato fermato da un estenzione';
$lang['Unknown upload error'] = 'Errore sconosciuto durante il trasferimento';
$lang['Error on file "%s" : %s'] = 'Errore sul file "%s" : %s';
$lang['Menu Management'] = 'Menu';
$lang['automatic order'] = 'Ordinamento automatico';
$lang['manual order'] = 'Ordinamento manuel';
$lang['Albums automatically sorted'] = 'Gli album sono stati ordinati automaticamente';

$lang['Keep high definition'] = 'Mantenere l\'alta definizione';
$lang['The high definition maximum width must be a number between %d and %d'] = 'La larghezza massima per l\'alta definizione deve essere un numero compreso tra %d e %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'L\'altezza massima per l\'alta definizione deve essere un numero compreso tra %d e %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'La qualità dell\'immagine per l\'alta definizione deve essere un numero compreso tra %d e %d';

$lang['Batch Manager'] = 'Gestione dei lotti';
$lang['include child albums'] = 'includere gli album dipendenti';
$lang['Selection'] = 'Selezione';
$lang['Action'] = 'Azione';
$lang['Set author'] = 'Definire l\'autore';
$lang['Set title'] = 'Impostare il titolo';
$lang['Set creation date'] = 'Impostare la data di creazione';
$lang['Apply action'] = 'Applicare l\'azione';
$lang['on the %d selected photos'] = 'sulle % foto selezionate';
$lang['%d of %d photos selected'] = '%d foto su %d sono selezionate';
$lang['No photo selected, %d photos in current set'] = 'Nessuna foto selezionata tra le %d foto del lotto';
$lang['All %d photos are selected'] = 'Tutte le %d foto del lotto sono selezionate';
$lang['remove this filter'] = 'cancellare questo filtro';
$lang['predefined filter'] = 'filtro predefinito';
$lang['last import'] = 'Ultima importazione';
$lang['with no virtual album'] = 'senza album virtuale';
$lang['duplicates'] = 'duplicati';
$lang['Add a filter'] = 'Aggiungere un filtro';
$lang['Remove all filters'] = 'Cancellare tutti i filtri';
$lang['Refresh photo set'] = 'Aggiornare il lotto di foto';
$lang['The whole page'] = 'Tutta la pagina';
$lang['The whole set'] = 'L\'intero lotto';
$lang['No photo in the current set.'] = 'Nessuna foto nel lotto.';
$lang['No photo selected, no action possible.'] = 'Nessuna foto selezionata, nessuna azione possibile.';
$lang['Choose an action'] = 'Selezionare un ricorso';
$lang['remove author'] = 'cancellare l\'autore';
$lang['Type here the author name'] = 'Inserire qui il nome dell\'autore';
$lang['remove title'] = 'cancellare il titolo';
$lang['Type here the title'] = 'Inserire qui il titolo';
$lang['remove creation date'] = 'cancellare la data di creazione';
$lang['with no album'] = 'senza album';
$lang['with no tag'] = 'senza tag';
$lang['Week starts on'] = 'La settimana comincia il';
$lang['You have %d orphan tags: %s.'] = 'Avete %d tags orfani : %s.';
$lang['Delete orphan tags'] = 'Cancellare i tags orfani';
$lang['delete photo'] = 'cancellare la foto';
$lang['Remove from caddie'] = 'Rimuovere dal cestino';
$lang['Themes which need upgrade'] = 'Temi che necessitano un aggiornamento';
$lang['Languages which need upgrade'] = 'Lingue che necessitano un aggiornamento ';
$lang['All themes are up to date.'] = 'Tutti i temi sono aggiornati.';
$lang['All plugins are up to date.'] = 'Tutti i plug-in sono aggiornati.';
$lang['All languages are up to date.'] = 'Tutte le lingue sono aggiornate.';
$lang['Visit theme site'] = 'Visitare il sito del tema';
$lang['Visit language site'] = 'Visitare il sito della lingua';
$lang['New Version'] = 'Nuova versione';
$lang['Obsolete Plugins'] = 'Plugins obsoleti';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'ATTENZIONE! Questo plugin non sembra essere compatibile con questa versione di Piwigo.';
$lang['Do you want to activate anyway?'] = 'Volete attivarlo comunque?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'QUESTO PLUGIN FA ORMAI PARTIE DEL CORE DI PIWIGO! CANCELLATELO.';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERRORE: QUESTO PLUGIN È MANCANTE MA TUTTORA INSTALLATO! CANCELLATELO.';
$lang['display'] = 'Visualizzare';
$lang['Restore'] = 'Restaurare';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Reimpostare la configurazione di defaut? Perderete tutte le vostre impostazioni!';
$lang['Regenerate Thumbnails'] = 'Rigenerare le miniature';
$lang['Regenerate Websize Photos'] = 'Rigenerare le foto dimensioni web';
$lang['Thumbnails generation in progress...'] = 'Rigenerazione delle miniature in corso ...';
$lang['Photos generation in progress...'] = 'Rigenerazione delle foto in corso ...';
$lang['%s thumbnails have been regenerated'] = '%s miniature sono state rigenerate';
$lang['%s thumbnails can not be regenerated'] = '%s miniature non possono essere rigenerate';
$lang['%s photos have been regenerated'] = '%s foto sono state rigenerate';
$lang['%s photos can not be regenerated'] = '%s foto non possono essere rigenerate';

$lang['Updates'] = 'Aggiornamento';
$lang['Update in progress... Please wait.'] = 'Aggiornamento in corso ... Attendere prego';
$lang['Ignore this update'] = 'Igniorare questo aggiornamento';
$lang['Reset ignored updates'] = 'Ripristinare gli aggiornamenti igniorati';
$lang['Update All'] = 'Applicare tutti gli aggiornamenti';
$lang['ERROR'] = 'ERRORE';
$lang['Update Complete'] = 'Aggiornamento completao';
$lang['Piwigo Update'] = 'Aggiornamento di Piwigo';
$lang['Extensions Update'] = 'Aggiornamento delle estenzioni';
$lang['All extensions are up to date.'] = 'Tutte le estensioni sono aggiorno';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'I plugin seguenti potrebbero non essere compatibili con la nuova versione di Piwigo :';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'I temi seguenti potrebbero non essere compatibili con la nuova versione di Piwigo :';
$lang['I decide to update anyway'] = 'Decido comunque di aggiornare';
$lang['Update to Piwigo %s'] = 'Aggiornare a Piwigo %s';
$lang['Two updates are available'] = 'Due aggiornamenti sono disponibili';
$lang['This is a minor update, with only bug corrections.'] = 'Questo è un aggiornamento minore, con solo correzioni di bug';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Questo è un aggiornamento importante, con <a href="%s">nuove e interessanti funzionalità</a>';
$lang['Some themes and plugins may be not available yet.'] = 'Alcuni temi e plugin possono non essere ancora disponibili';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'È possibile aggiornare direttamente a Piwigo %s, senza passare per Piwigo %s (consigliato)';
$lang['Save Template Directory'] = 'Salvare la template directory';
$lang['Dump Database'] = 'Salvare il database';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Includere la cronologia (Attenzione: può essere superato il limite di memoria del server)';
$lang['Unable to write new local directory.'] = 'Impossibile creare nuove directory locali';
$lang['Unable to send template directory.'] = 'Impossibile inviare la directory template';
$lang['Unable to dump database.'] = 'Impossibile eseguire il salvataggio del database';
$lang['Some upgrades are available for extensions.'] = 'Degli aggiornamenti sono disponibili per le estenzioni';
$lang['Please wait...'] = 'Attendere prego ...';
$lang['Ignore All'] = 'Igniorare tutti gli aggiornamenti';
$lang['Crop'] = 'Ridimenzionare';
$lang['Width'] = 'Larghezza';
$lang['Height'] = 'Altezza';
$lang['Follow Orientation'] = 'Rispettare l\'orientamento';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Se volete rigenerare le miniature, rendetevi su <a href="%s">Gestione per lotti</a>.';
$lang['Graphics Library'] = 'Biblioteca grafica';
$lang['Show menubar'] = 'Visualizzare il menu';
$lang['No results'] = 'Nessun risultato';
$lang['Type in a search term'] = 'Inserire un Entrez un termine di ricerca';
$lang['Searching...'] = 'Ricerca ...';
$lang['new'] = 'nuovo';
$lang['Default photos order'] = 'Ordinamento di default delle foto';
$lang['Activate icon "new" next to albums and pictures'] = 'Visualizzare l\'icona "nuovo" a fianco degli album e delle foto';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Non potete impostare l\'ordine predefinito delle foto perché avete un\'impostazione personalizzata nella configurazione locale';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Avete specificato <i>$conf[\'order_by\']</i> nel vostro file di configurazione, questo parametro è obsoleto, si prega di eliminarlo o rinominarlo in <i>$conf[\'order_by_custom\']</i> !';
$lang['Add a criteria'] = 'Aggiungere un criterio';
$lang['... or '] = '... oppure ';
$lang['Create'] = 'Creare';
$lang['Start Upload'] = 'Avviare il trasferimento';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Uzate il modulo Flash. Dei problemi? Provate allora con il <a href="%s">modulo HTML</a>';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Uzate il modulo HTML. Provate con il <a href="%s">modulo Flash</a>';
$lang['Maximum file size: %sB.'] = 'Grandezza massima dei file : %sB.';
$lang['Allowed file types: %s.'] = 'Tipi di file autorizzati : %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Risoluzione massima approssimativa : %dM pixels (sia %dx%d pixels)';
$lang['Manage Permissions'] = 'Gestire i permessi';
$lang['Photo %s of %s'] = 'Foto %s su %s';
$lang['show details'] = 'mostrare i dettagli';
$lang['hide details'] = 'nascondere i dettagli';
$lang['Merge tags'] = 'Fusionare i tags';
$lang['Select the destination tag'] = 'Selezionare il tag di destinazione';
$lang['(this tag will be deleted)'] = '(questo tag sara cancellato)';
$lang['Confirm merge'] = 'Confermare la fusione';
$lang['Merge selected tags'] = 'Fusionare i tags selezionati';
$lang['No destination tag selected'] = 'Non avete selezionato il tag di destinazione';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'i tags <em>%s</em> sono stati fuzionati nel tag <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Selezionare almeno due tag da fuzionare';
$lang['Average rate'] = 'Voto medio';
$lang['Rate'] = 'Voto';
$lang['Learn more'] = 'Per saperne di più';
$lang['Select an album'] = 'Selezionare un album';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Di default, Piwigo creera la nuova foto dimensioni web a partire della foto HD (alta definizione)';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Se la foto HD non è disponibile e la foto dimensioni web è più grande delle dimensioni qui di seguito, allora Piwigo la considererà come una foto HD e creera la nuova foto dimensioni web';
$lang['An error has occured during upgrade.'] = 'Si è verificato un\'errore durante l\'aggiornamento';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Non è stato possibile estrarre i file. Verificare i permessi dei file della vostra installazione.<br><a href="%s">Cliccare qui per visualizzare il rapporto d\'errore</a>';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo non può recuperare i file d\'aggiornamento dal server';
?>